package com.jdbernard.timeanalyzer.processors

import com.jdbernard.timeanalyzer.events.Event
import com.jdbernard.timestamper.core.Timeline
import com.jdbernard.timestamper.core.TimelineProperties
import org.joda.time.DateTime
import org.joda.time.Duration

public class TimelineEventProcessor {

    /** Events whose description matches one of these regex strings or
      * patterns are ignored. */
    List exclusions = []

    public TimelineEventProcessor() {}

    public TimelineEventProcessor(List exclusions) { this.exclusions = exclusions }

    public List<Event> process(File timelinePropFile) {
        def timelineProps = new TimelineProperties(timelinePropFile)
        return process(timelineProps.timeline) }

    public List<Event> process(Timeline timeline) {
        List<Event> events = []

        timeline.each { marker ->
            Event e = new Event(
                description: marker.mark,
                notes: marker.notes,
                start: new DateTime(marker.timestamp),
                duration: new Duration(0))

            println e

            // if this is not the first event, then we need to update the
            // duration of the previous event
            if (events.size > 0) {
                Event lastEvent = events[-1]
                lastEvent.duration = new Duration(lastEvent.start, e.start) }

            events << e }

        def excluded = events.findAll { event ->
            exclusions.any { exclusion -> event.description ==~ exclusion } }

        return events - excluded }

    public static List<Event> process(def timeline, List exclusions) {
        def inst = new TimelineEventProcessor(exclusions)
        return inst.process(timeline) }
}
